from __future__ import annotations

from typing import Optional, Dict, Any

from ...pretrained import WhisperV1Tokenizer

__all__ = ["DistilledWhisperEnglishTokenizer"]

class DistilledWhisperEnglishTokenizer(WhisperV1Tokenizer):
    """
    The tokenizer for Distilled Whisper English models.
    """
    init_file_urls = {
        "vocab_file": "https://huggingface.co/benjamin-paine/taproot-common/resolve/main/audio-transcription-distilled-whisper-english-tokenizer-vocab.json",
        "merges_file": "https://huggingface.co/benjamin-paine/taproot-common/resolve/main/audio-transcription-distilled-whisper-english-tokenizer-merges.txt",
        "normalizer_file": "https://huggingface.co/benjamin-paine/taproot-common/resolve/main/audio-transcription-distilled-whisper-english-tokenizer-normalizer.json",
        "tokenizer_file": "https://huggingface.co/benjamin-paine/taproot-common/resolve/main/audio-transcription-distillled-whisper-english-tokenizer.json",
    }

    @classmethod
    def get_default_config(cls) -> Optional[Dict[str, Any]]:
        """
        Get the default configuration for the Distilled Whisper English Tokenizer.
        """
        config = {
            "add_bos_token": False,
            "add_prefix_space": False,
            "added_tokens_decoder": {
                "50256": {
                    "content": "<|endoftext|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": True,
                },
                "50257": {
                    "content": "<|startoftranscript|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50258": {
                    "content": "<|en|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50259": {
                    "content": "<|zh|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50260": {
                    "content": "<|de|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50261": {
                    "content": "<|es|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50262": {
                    "content": "<|ru|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50263": {
                    "content": "<|ko|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50264": {
                    "content": "<|fr|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50265": {
                    "content": "<|ja|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50266": {
                    "content": "<|pt|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50267": {
                    "content": "<|tr|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50268": {
                    "content": "<|pl|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50269": {
                    "content": "<|ca|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50270": {
                    "content": "<|nl|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50271": {
                    "content": "<|ar|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50272": {
                    "content": "<|sv|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50273": {
                    "content": "<|it|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50274": {
                    "content": "<|id|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50275": {
                    "content": "<|hi|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50276": {
                    "content": "<|fi|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50277": {
                    "content": "<|vi|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50278": {
                    "content": "<|iw|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50279": {
                    "content": "<|uk|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50280": {
                    "content": "<|el|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50281": {
                    "content": "<|ms|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50282": {
                    "content": "<|cs|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50283": {
                    "content": "<|ro|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50284": {
                    "content": "<|da|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50285": {
                    "content": "<|hu|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50286": {
                    "content": "<|ta|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50287": {
                    "content": "<|no|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50288": {
                    "content": "<|th|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50289": {
                    "content": "<|ur|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50290": {
                    "content": "<|hr|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50291": {
                    "content": "<|bg|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50292": {
                    "content": "<|lt|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50293": {
                    "content": "<|la|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50294": {
                    "content": "<|mi|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50295": {
                    "content": "<|ml|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50296": {
                    "content": "<|cy|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50297": {
                    "content": "<|sk|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50298": {
                    "content": "<|te|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50299": {
                    "content": "<|fa|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50300": {
                    "content": "<|lv|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50301": {
                    "content": "<|bn|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50302": {
                    "content": "<|sr|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50303": {
                    "content": "<|az|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50304": {
                    "content": "<|sl|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50305": {
                    "content": "<|kn|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50306": {
                    "content": "<|et|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50307": {
                    "content": "<|mk|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50308": {
                    "content": "<|br|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50309": {
                    "content": "<|eu|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50310": {
                    "content": "<|is|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50311": {
                    "content": "<|hy|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50312": {
                    "content": "<|ne|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50313": {
                    "content": "<|mn|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50314": {
                    "content": "<|bs|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50315": {
                    "content": "<|kk|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50316": {
                    "content": "<|sq|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50317": {
                    "content": "<|sw|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50318": {
                    "content": "<|gl|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50319": {
                    "content": "<|mr|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50320": {
                    "content": "<|pa|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50321": {
                    "content": "<|si|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50322": {
                    "content": "<|km|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50323": {
                    "content": "<|sn|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50324": {
                    "content": "<|yo|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50325": {
                    "content": "<|so|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50326": {
                    "content": "<|af|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50327": {
                    "content": "<|oc|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50328": {
                    "content": "<|ka|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50329": {
                    "content": "<|be|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50330": {
                    "content": "<|tg|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50331": {
                    "content": "<|sd|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50332": {
                    "content": "<|gu|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50333": {
                    "content": "<|am|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50334": {
                    "content": "<|yi|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50335": {
                    "content": "<|lo|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50336": {
                    "content": "<|uz|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50337": {
                    "content": "<|fo|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50338": {
                    "content": "<|ht|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50339": {
                    "content": "<|ps|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50340": {
                    "content": "<|tk|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50341": {
                    "content": "<|nn|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50342": {
                    "content": "<|mt|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50343": {
                    "content": "<|sa|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50344": {
                    "content": "<|lb|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50345": {
                    "content": "<|my|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50346": {
                    "content": "<|bo|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50347": {
                    "content": "<|tl|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50348": {
                    "content": "<|mg|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50349": {
                    "content": "<|as|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50350": {
                    "content": "<|tt|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50351": {
                    "content": "<|haw|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50352": {
                    "content": "<|ln|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50353": {
                    "content": "<|ha|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50354": {
                    "content": "<|ba|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50355": {
                    "content": "<|jw|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50356": {
                    "content": "<|su|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50357": {
                    "content": "<|translate|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50358": {
                    "content": "<|transcribe|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50359": {
                    "content": "<|startoflm|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50360": {
                    "content": "<|startofprev|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50361": {
                    "content": "<|nocaptions|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50362": {
                    "content": "<|notimestamps|>",
                    "lstrip": True,
                    "normalized": False,
                    "rstrip": True,
                    "single_word": False,
                    "special": True,
                },
                "50363": {
                    "content": "<|0.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50364": {
                    "content": "<|0.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50365": {
                    "content": "<|0.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50366": {
                    "content": "<|0.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50367": {
                    "content": "<|0.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50368": {
                    "content": "<|0.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50369": {
                    "content": "<|0.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50370": {
                    "content": "<|0.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50371": {
                    "content": "<|0.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50372": {
                    "content": "<|0.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50373": {
                    "content": "<|0.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50374": {
                    "content": "<|0.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50375": {
                    "content": "<|0.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50376": {
                    "content": "<|0.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50377": {
                    "content": "<|0.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50378": {
                    "content": "<|0.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50379": {
                    "content": "<|0.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50380": {
                    "content": "<|0.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50381": {
                    "content": "<|0.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50382": {
                    "content": "<|0.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50383": {
                    "content": "<|0.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50384": {
                    "content": "<|0.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50385": {
                    "content": "<|0.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50386": {
                    "content": "<|0.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50387": {
                    "content": "<|0.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50388": {
                    "content": "<|0.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50389": {
                    "content": "<|0.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50390": {
                    "content": "<|0.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50391": {
                    "content": "<|0.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50392": {
                    "content": "<|0.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50393": {
                    "content": "<|0.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50394": {
                    "content": "<|0.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50395": {
                    "content": "<|0.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50396": {
                    "content": "<|0.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50397": {
                    "content": "<|0.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50398": {
                    "content": "<|0.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50399": {
                    "content": "<|0.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50400": {
                    "content": "<|0.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50401": {
                    "content": "<|0.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50402": {
                    "content": "<|0.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50403": {
                    "content": "<|0.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50404": {
                    "content": "<|0.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50405": {
                    "content": "<|0.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50406": {
                    "content": "<|0.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50407": {
                    "content": "<|0.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50408": {
                    "content": "<|0.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50409": {
                    "content": "<|0.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50410": {
                    "content": "<|0.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50411": {
                    "content": "<|0.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50412": {
                    "content": "<|0.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50413": {
                    "content": "<|1.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50414": {
                    "content": "<|1.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50415": {
                    "content": "<|1.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50416": {
                    "content": "<|1.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50417": {
                    "content": "<|1.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50418": {
                    "content": "<|1.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50419": {
                    "content": "<|1.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50420": {
                    "content": "<|1.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50421": {
                    "content": "<|1.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50422": {
                    "content": "<|1.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50423": {
                    "content": "<|1.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50424": {
                    "content": "<|1.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50425": {
                    "content": "<|1.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50426": {
                    "content": "<|1.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50427": {
                    "content": "<|1.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50428": {
                    "content": "<|1.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50429": {
                    "content": "<|1.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50430": {
                    "content": "<|1.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50431": {
                    "content": "<|1.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50432": {
                    "content": "<|1.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50433": {
                    "content": "<|1.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50434": {
                    "content": "<|1.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50435": {
                    "content": "<|1.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50436": {
                    "content": "<|1.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50437": {
                    "content": "<|1.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50438": {
                    "content": "<|1.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50439": {
                    "content": "<|1.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50440": {
                    "content": "<|1.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50441": {
                    "content": "<|1.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50442": {
                    "content": "<|1.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50443": {
                    "content": "<|1.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50444": {
                    "content": "<|1.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50445": {
                    "content": "<|1.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50446": {
                    "content": "<|1.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50447": {
                    "content": "<|1.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50448": {
                    "content": "<|1.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50449": {
                    "content": "<|1.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50450": {
                    "content": "<|1.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50451": {
                    "content": "<|1.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50452": {
                    "content": "<|1.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50453": {
                    "content": "<|1.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50454": {
                    "content": "<|1.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50455": {
                    "content": "<|1.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50456": {
                    "content": "<|1.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50457": {
                    "content": "<|1.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50458": {
                    "content": "<|1.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50459": {
                    "content": "<|1.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50460": {
                    "content": "<|1.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50461": {
                    "content": "<|1.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50462": {
                    "content": "<|1.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50463": {
                    "content": "<|2.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50464": {
                    "content": "<|2.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50465": {
                    "content": "<|2.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50466": {
                    "content": "<|2.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50467": {
                    "content": "<|2.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50468": {
                    "content": "<|2.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50469": {
                    "content": "<|2.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50470": {
                    "content": "<|2.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50471": {
                    "content": "<|2.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50472": {
                    "content": "<|2.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50473": {
                    "content": "<|2.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50474": {
                    "content": "<|2.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50475": {
                    "content": "<|2.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50476": {
                    "content": "<|2.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50477": {
                    "content": "<|2.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50478": {
                    "content": "<|2.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50479": {
                    "content": "<|2.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50480": {
                    "content": "<|2.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50481": {
                    "content": "<|2.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50482": {
                    "content": "<|2.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50483": {
                    "content": "<|2.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50484": {
                    "content": "<|2.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50485": {
                    "content": "<|2.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50486": {
                    "content": "<|2.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50487": {
                    "content": "<|2.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50488": {
                    "content": "<|2.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50489": {
                    "content": "<|2.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50490": {
                    "content": "<|2.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50491": {
                    "content": "<|2.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50492": {
                    "content": "<|2.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50493": {
                    "content": "<|2.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50494": {
                    "content": "<|2.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50495": {
                    "content": "<|2.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50496": {
                    "content": "<|2.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50497": {
                    "content": "<|2.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50498": {
                    "content": "<|2.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50499": {
                    "content": "<|2.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50500": {
                    "content": "<|2.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50501": {
                    "content": "<|2.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50502": {
                    "content": "<|2.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50503": {
                    "content": "<|2.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50504": {
                    "content": "<|2.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50505": {
                    "content": "<|2.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50506": {
                    "content": "<|2.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50507": {
                    "content": "<|2.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50508": {
                    "content": "<|2.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50509": {
                    "content": "<|2.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50510": {
                    "content": "<|2.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50511": {
                    "content": "<|2.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50512": {
                    "content": "<|2.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50513": {
                    "content": "<|3.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50514": {
                    "content": "<|3.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50515": {
                    "content": "<|3.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50516": {
                    "content": "<|3.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50517": {
                    "content": "<|3.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50518": {
                    "content": "<|3.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50519": {
                    "content": "<|3.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50520": {
                    "content": "<|3.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50521": {
                    "content": "<|3.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50522": {
                    "content": "<|3.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50523": {
                    "content": "<|3.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50524": {
                    "content": "<|3.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50525": {
                    "content": "<|3.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50526": {
                    "content": "<|3.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50527": {
                    "content": "<|3.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50528": {
                    "content": "<|3.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50529": {
                    "content": "<|3.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50530": {
                    "content": "<|3.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50531": {
                    "content": "<|3.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50532": {
                    "content": "<|3.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50533": {
                    "content": "<|3.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50534": {
                    "content": "<|3.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50535": {
                    "content": "<|3.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50536": {
                    "content": "<|3.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50537": {
                    "content": "<|3.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50538": {
                    "content": "<|3.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50539": {
                    "content": "<|3.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50540": {
                    "content": "<|3.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50541": {
                    "content": "<|3.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50542": {
                    "content": "<|3.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50543": {
                    "content": "<|3.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50544": {
                    "content": "<|3.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50545": {
                    "content": "<|3.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50546": {
                    "content": "<|3.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50547": {
                    "content": "<|3.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50548": {
                    "content": "<|3.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50549": {
                    "content": "<|3.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50550": {
                    "content": "<|3.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50551": {
                    "content": "<|3.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50552": {
                    "content": "<|3.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50553": {
                    "content": "<|3.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50554": {
                    "content": "<|3.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50555": {
                    "content": "<|3.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50556": {
                    "content": "<|3.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50557": {
                    "content": "<|3.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50558": {
                    "content": "<|3.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50559": {
                    "content": "<|3.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50560": {
                    "content": "<|3.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50561": {
                    "content": "<|3.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50562": {
                    "content": "<|3.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50563": {
                    "content": "<|4.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50564": {
                    "content": "<|4.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50565": {
                    "content": "<|4.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50566": {
                    "content": "<|4.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50567": {
                    "content": "<|4.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50568": {
                    "content": "<|4.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50569": {
                    "content": "<|4.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50570": {
                    "content": "<|4.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50571": {
                    "content": "<|4.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50572": {
                    "content": "<|4.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50573": {
                    "content": "<|4.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50574": {
                    "content": "<|4.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50575": {
                    "content": "<|4.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50576": {
                    "content": "<|4.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50577": {
                    "content": "<|4.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50578": {
                    "content": "<|4.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50579": {
                    "content": "<|4.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50580": {
                    "content": "<|4.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50581": {
                    "content": "<|4.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50582": {
                    "content": "<|4.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50583": {
                    "content": "<|4.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50584": {
                    "content": "<|4.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50585": {
                    "content": "<|4.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50586": {
                    "content": "<|4.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50587": {
                    "content": "<|4.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50588": {
                    "content": "<|4.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50589": {
                    "content": "<|4.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50590": {
                    "content": "<|4.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50591": {
                    "content": "<|4.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50592": {
                    "content": "<|4.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50593": {
                    "content": "<|4.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50594": {
                    "content": "<|4.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50595": {
                    "content": "<|4.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50596": {
                    "content": "<|4.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50597": {
                    "content": "<|4.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50598": {
                    "content": "<|4.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50599": {
                    "content": "<|4.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50600": {
                    "content": "<|4.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50601": {
                    "content": "<|4.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50602": {
                    "content": "<|4.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50603": {
                    "content": "<|4.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50604": {
                    "content": "<|4.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50605": {
                    "content": "<|4.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50606": {
                    "content": "<|4.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50607": {
                    "content": "<|4.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50608": {
                    "content": "<|4.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50609": {
                    "content": "<|4.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50610": {
                    "content": "<|4.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50611": {
                    "content": "<|4.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50612": {
                    "content": "<|4.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50613": {
                    "content": "<|5.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50614": {
                    "content": "<|5.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50615": {
                    "content": "<|5.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50616": {
                    "content": "<|5.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50617": {
                    "content": "<|5.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50618": {
                    "content": "<|5.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50619": {
                    "content": "<|5.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50620": {
                    "content": "<|5.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50621": {
                    "content": "<|5.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50622": {
                    "content": "<|5.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50623": {
                    "content": "<|5.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50624": {
                    "content": "<|5.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50625": {
                    "content": "<|5.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50626": {
                    "content": "<|5.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50627": {
                    "content": "<|5.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50628": {
                    "content": "<|5.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50629": {
                    "content": "<|5.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50630": {
                    "content": "<|5.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50631": {
                    "content": "<|5.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50632": {
                    "content": "<|5.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50633": {
                    "content": "<|5.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50634": {
                    "content": "<|5.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50635": {
                    "content": "<|5.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50636": {
                    "content": "<|5.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50637": {
                    "content": "<|5.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50638": {
                    "content": "<|5.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50639": {
                    "content": "<|5.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50640": {
                    "content": "<|5.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50641": {
                    "content": "<|5.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50642": {
                    "content": "<|5.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50643": {
                    "content": "<|5.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50644": {
                    "content": "<|5.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50645": {
                    "content": "<|5.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50646": {
                    "content": "<|5.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50647": {
                    "content": "<|5.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50648": {
                    "content": "<|5.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50649": {
                    "content": "<|5.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50650": {
                    "content": "<|5.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50651": {
                    "content": "<|5.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50652": {
                    "content": "<|5.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50653": {
                    "content": "<|5.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50654": {
                    "content": "<|5.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50655": {
                    "content": "<|5.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50656": {
                    "content": "<|5.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50657": {
                    "content": "<|5.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50658": {
                    "content": "<|5.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50659": {
                    "content": "<|5.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50660": {
                    "content": "<|5.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50661": {
                    "content": "<|5.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50662": {
                    "content": "<|5.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50663": {
                    "content": "<|6.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50664": {
                    "content": "<|6.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50665": {
                    "content": "<|6.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50666": {
                    "content": "<|6.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50667": {
                    "content": "<|6.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50668": {
                    "content": "<|6.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50669": {
                    "content": "<|6.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50670": {
                    "content": "<|6.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50671": {
                    "content": "<|6.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50672": {
                    "content": "<|6.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50673": {
                    "content": "<|6.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50674": {
                    "content": "<|6.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50675": {
                    "content": "<|6.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50676": {
                    "content": "<|6.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50677": {
                    "content": "<|6.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50678": {
                    "content": "<|6.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50679": {
                    "content": "<|6.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50680": {
                    "content": "<|6.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50681": {
                    "content": "<|6.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50682": {
                    "content": "<|6.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50683": {
                    "content": "<|6.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50684": {
                    "content": "<|6.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50685": {
                    "content": "<|6.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50686": {
                    "content": "<|6.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50687": {
                    "content": "<|6.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50688": {
                    "content": "<|6.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50689": {
                    "content": "<|6.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50690": {
                    "content": "<|6.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50691": {
                    "content": "<|6.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50692": {
                    "content": "<|6.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50693": {
                    "content": "<|6.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50694": {
                    "content": "<|6.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50695": {
                    "content": "<|6.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50696": {
                    "content": "<|6.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50697": {
                    "content": "<|6.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50698": {
                    "content": "<|6.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50699": {
                    "content": "<|6.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50700": {
                    "content": "<|6.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50701": {
                    "content": "<|6.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50702": {
                    "content": "<|6.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50703": {
                    "content": "<|6.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50704": {
                    "content": "<|6.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50705": {
                    "content": "<|6.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50706": {
                    "content": "<|6.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50707": {
                    "content": "<|6.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50708": {
                    "content": "<|6.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50709": {
                    "content": "<|6.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50710": {
                    "content": "<|6.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50711": {
                    "content": "<|6.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50712": {
                    "content": "<|6.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50713": {
                    "content": "<|7.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50714": {
                    "content": "<|7.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50715": {
                    "content": "<|7.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50716": {
                    "content": "<|7.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50717": {
                    "content": "<|7.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50718": {
                    "content": "<|7.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50719": {
                    "content": "<|7.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50720": {
                    "content": "<|7.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50721": {
                    "content": "<|7.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50722": {
                    "content": "<|7.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50723": {
                    "content": "<|7.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50724": {
                    "content": "<|7.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50725": {
                    "content": "<|7.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50726": {
                    "content": "<|7.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50727": {
                    "content": "<|7.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50728": {
                    "content": "<|7.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50729": {
                    "content": "<|7.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50730": {
                    "content": "<|7.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50731": {
                    "content": "<|7.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50732": {
                    "content": "<|7.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50733": {
                    "content": "<|7.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50734": {
                    "content": "<|7.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50735": {
                    "content": "<|7.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50736": {
                    "content": "<|7.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50737": {
                    "content": "<|7.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50738": {
                    "content": "<|7.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50739": {
                    "content": "<|7.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50740": {
                    "content": "<|7.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50741": {
                    "content": "<|7.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50742": {
                    "content": "<|7.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50743": {
                    "content": "<|7.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50744": {
                    "content": "<|7.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50745": {
                    "content": "<|7.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50746": {
                    "content": "<|7.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50747": {
                    "content": "<|7.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50748": {
                    "content": "<|7.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50749": {
                    "content": "<|7.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50750": {
                    "content": "<|7.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50751": {
                    "content": "<|7.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50752": {
                    "content": "<|7.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50753": {
                    "content": "<|7.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50754": {
                    "content": "<|7.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50755": {
                    "content": "<|7.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50756": {
                    "content": "<|7.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50757": {
                    "content": "<|7.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50758": {
                    "content": "<|7.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50759": {
                    "content": "<|7.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50760": {
                    "content": "<|7.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50761": {
                    "content": "<|7.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50762": {
                    "content": "<|7.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50763": {
                    "content": "<|8.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50764": {
                    "content": "<|8.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50765": {
                    "content": "<|8.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50766": {
                    "content": "<|8.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50767": {
                    "content": "<|8.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50768": {
                    "content": "<|8.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50769": {
                    "content": "<|8.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50770": {
                    "content": "<|8.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50771": {
                    "content": "<|8.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50772": {
                    "content": "<|8.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50773": {
                    "content": "<|8.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50774": {
                    "content": "<|8.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50775": {
                    "content": "<|8.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50776": {
                    "content": "<|8.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50777": {
                    "content": "<|8.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50778": {
                    "content": "<|8.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50779": {
                    "content": "<|8.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50780": {
                    "content": "<|8.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50781": {
                    "content": "<|8.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50782": {
                    "content": "<|8.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50783": {
                    "content": "<|8.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50784": {
                    "content": "<|8.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50785": {
                    "content": "<|8.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50786": {
                    "content": "<|8.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50787": {
                    "content": "<|8.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50788": {
                    "content": "<|8.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50789": {
                    "content": "<|8.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50790": {
                    "content": "<|8.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50791": {
                    "content": "<|8.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50792": {
                    "content": "<|8.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50793": {
                    "content": "<|8.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50794": {
                    "content": "<|8.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50795": {
                    "content": "<|8.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50796": {
                    "content": "<|8.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50797": {
                    "content": "<|8.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50798": {
                    "content": "<|8.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50799": {
                    "content": "<|8.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50800": {
                    "content": "<|8.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50801": {
                    "content": "<|8.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50802": {
                    "content": "<|8.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50803": {
                    "content": "<|8.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50804": {
                    "content": "<|8.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50805": {
                    "content": "<|8.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50806": {
                    "content": "<|8.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50807": {
                    "content": "<|8.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50808": {
                    "content": "<|8.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50809": {
                    "content": "<|8.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50810": {
                    "content": "<|8.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50811": {
                    "content": "<|8.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50812": {
                    "content": "<|8.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50813": {
                    "content": "<|9.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50814": {
                    "content": "<|9.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50815": {
                    "content": "<|9.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50816": {
                    "content": "<|9.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50817": {
                    "content": "<|9.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50818": {
                    "content": "<|9.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50819": {
                    "content": "<|9.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50820": {
                    "content": "<|9.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50821": {
                    "content": "<|9.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50822": {
                    "content": "<|9.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50823": {
                    "content": "<|9.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50824": {
                    "content": "<|9.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50825": {
                    "content": "<|9.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50826": {
                    "content": "<|9.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50827": {
                    "content": "<|9.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50828": {
                    "content": "<|9.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50829": {
                    "content": "<|9.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50830": {
                    "content": "<|9.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50831": {
                    "content": "<|9.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50832": {
                    "content": "<|9.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50833": {
                    "content": "<|9.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50834": {
                    "content": "<|9.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50835": {
                    "content": "<|9.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50836": {
                    "content": "<|9.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50837": {
                    "content": "<|9.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50838": {
                    "content": "<|9.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50839": {
                    "content": "<|9.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50840": {
                    "content": "<|9.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50841": {
                    "content": "<|9.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50842": {
                    "content": "<|9.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50843": {
                    "content": "<|9.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50844": {
                    "content": "<|9.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50845": {
                    "content": "<|9.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50846": {
                    "content": "<|9.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50847": {
                    "content": "<|9.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50848": {
                    "content": "<|9.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50849": {
                    "content": "<|9.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50850": {
                    "content": "<|9.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50851": {
                    "content": "<|9.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50852": {
                    "content": "<|9.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50853": {
                    "content": "<|9.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50854": {
                    "content": "<|9.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50855": {
                    "content": "<|9.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50856": {
                    "content": "<|9.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50857": {
                    "content": "<|9.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50858": {
                    "content": "<|9.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50859": {
                    "content": "<|9.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50860": {
                    "content": "<|9.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50861": {
                    "content": "<|9.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50862": {
                    "content": "<|9.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50863": {
                    "content": "<|10.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50864": {
                    "content": "<|10.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50865": {
                    "content": "<|10.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50866": {
                    "content": "<|10.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50867": {
                    "content": "<|10.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50868": {
                    "content": "<|10.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50869": {
                    "content": "<|10.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50870": {
                    "content": "<|10.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50871": {
                    "content": "<|10.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50872": {
                    "content": "<|10.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50873": {
                    "content": "<|10.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50874": {
                    "content": "<|10.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50875": {
                    "content": "<|10.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50876": {
                    "content": "<|10.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50877": {
                    "content": "<|10.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50878": {
                    "content": "<|10.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50879": {
                    "content": "<|10.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50880": {
                    "content": "<|10.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50881": {
                    "content": "<|10.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50882": {
                    "content": "<|10.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50883": {
                    "content": "<|10.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50884": {
                    "content": "<|10.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50885": {
                    "content": "<|10.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50886": {
                    "content": "<|10.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50887": {
                    "content": "<|10.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50888": {
                    "content": "<|10.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50889": {
                    "content": "<|10.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50890": {
                    "content": "<|10.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50891": {
                    "content": "<|10.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50892": {
                    "content": "<|10.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50893": {
                    "content": "<|10.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50894": {
                    "content": "<|10.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50895": {
                    "content": "<|10.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50896": {
                    "content": "<|10.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50897": {
                    "content": "<|10.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50898": {
                    "content": "<|10.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50899": {
                    "content": "<|10.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50900": {
                    "content": "<|10.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50901": {
                    "content": "<|10.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50902": {
                    "content": "<|10.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50903": {
                    "content": "<|10.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50904": {
                    "content": "<|10.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50905": {
                    "content": "<|10.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50906": {
                    "content": "<|10.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50907": {
                    "content": "<|10.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50908": {
                    "content": "<|10.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50909": {
                    "content": "<|10.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50910": {
                    "content": "<|10.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50911": {
                    "content": "<|10.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50912": {
                    "content": "<|10.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50913": {
                    "content": "<|11.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50914": {
                    "content": "<|11.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50915": {
                    "content": "<|11.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50916": {
                    "content": "<|11.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50917": {
                    "content": "<|11.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50918": {
                    "content": "<|11.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50919": {
                    "content": "<|11.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50920": {
                    "content": "<|11.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50921": {
                    "content": "<|11.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50922": {
                    "content": "<|11.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50923": {
                    "content": "<|11.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50924": {
                    "content": "<|11.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50925": {
                    "content": "<|11.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50926": {
                    "content": "<|11.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50927": {
                    "content": "<|11.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50928": {
                    "content": "<|11.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50929": {
                    "content": "<|11.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50930": {
                    "content": "<|11.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50931": {
                    "content": "<|11.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50932": {
                    "content": "<|11.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50933": {
                    "content": "<|11.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50934": {
                    "content": "<|11.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50935": {
                    "content": "<|11.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50936": {
                    "content": "<|11.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50937": {
                    "content": "<|11.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50938": {
                    "content": "<|11.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50939": {
                    "content": "<|11.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50940": {
                    "content": "<|11.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50941": {
                    "content": "<|11.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50942": {
                    "content": "<|11.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50943": {
                    "content": "<|11.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50944": {
                    "content": "<|11.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50945": {
                    "content": "<|11.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50946": {
                    "content": "<|11.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50947": {
                    "content": "<|11.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50948": {
                    "content": "<|11.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50949": {
                    "content": "<|11.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50950": {
                    "content": "<|11.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50951": {
                    "content": "<|11.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50952": {
                    "content": "<|11.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50953": {
                    "content": "<|11.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50954": {
                    "content": "<|11.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50955": {
                    "content": "<|11.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50956": {
                    "content": "<|11.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50957": {
                    "content": "<|11.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50958": {
                    "content": "<|11.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50959": {
                    "content": "<|11.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50960": {
                    "content": "<|11.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50961": {
                    "content": "<|11.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50962": {
                    "content": "<|11.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50963": {
                    "content": "<|12.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50964": {
                    "content": "<|12.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50965": {
                    "content": "<|12.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50966": {
                    "content": "<|12.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50967": {
                    "content": "<|12.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50968": {
                    "content": "<|12.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50969": {
                    "content": "<|12.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50970": {
                    "content": "<|12.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50971": {
                    "content": "<|12.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50972": {
                    "content": "<|12.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50973": {
                    "content": "<|12.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50974": {
                    "content": "<|12.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50975": {
                    "content": "<|12.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50976": {
                    "content": "<|12.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50977": {
                    "content": "<|12.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50978": {
                    "content": "<|12.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50979": {
                    "content": "<|12.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50980": {
                    "content": "<|12.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50981": {
                    "content": "<|12.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50982": {
                    "content": "<|12.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50983": {
                    "content": "<|12.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50984": {
                    "content": "<|12.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50985": {
                    "content": "<|12.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50986": {
                    "content": "<|12.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50987": {
                    "content": "<|12.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50988": {
                    "content": "<|12.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50989": {
                    "content": "<|12.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50990": {
                    "content": "<|12.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50991": {
                    "content": "<|12.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50992": {
                    "content": "<|12.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50993": {
                    "content": "<|12.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50994": {
                    "content": "<|12.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50995": {
                    "content": "<|12.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50996": {
                    "content": "<|12.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50997": {
                    "content": "<|12.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50998": {
                    "content": "<|12.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "50999": {
                    "content": "<|12.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51000": {
                    "content": "<|12.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51001": {
                    "content": "<|12.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51002": {
                    "content": "<|12.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51003": {
                    "content": "<|12.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51004": {
                    "content": "<|12.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51005": {
                    "content": "<|12.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51006": {
                    "content": "<|12.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51007": {
                    "content": "<|12.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51008": {
                    "content": "<|12.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51009": {
                    "content": "<|12.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51010": {
                    "content": "<|12.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51011": {
                    "content": "<|12.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51012": {
                    "content": "<|12.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51013": {
                    "content": "<|13.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51014": {
                    "content": "<|13.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51015": {
                    "content": "<|13.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51016": {
                    "content": "<|13.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51017": {
                    "content": "<|13.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51018": {
                    "content": "<|13.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51019": {
                    "content": "<|13.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51020": {
                    "content": "<|13.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51021": {
                    "content": "<|13.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51022": {
                    "content": "<|13.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51023": {
                    "content": "<|13.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51024": {
                    "content": "<|13.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51025": {
                    "content": "<|13.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51026": {
                    "content": "<|13.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51027": {
                    "content": "<|13.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51028": {
                    "content": "<|13.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51029": {
                    "content": "<|13.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51030": {
                    "content": "<|13.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51031": {
                    "content": "<|13.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51032": {
                    "content": "<|13.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51033": {
                    "content": "<|13.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51034": {
                    "content": "<|13.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51035": {
                    "content": "<|13.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51036": {
                    "content": "<|13.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51037": {
                    "content": "<|13.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51038": {
                    "content": "<|13.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51039": {
                    "content": "<|13.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51040": {
                    "content": "<|13.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51041": {
                    "content": "<|13.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51042": {
                    "content": "<|13.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51043": {
                    "content": "<|13.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51044": {
                    "content": "<|13.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51045": {
                    "content": "<|13.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51046": {
                    "content": "<|13.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51047": {
                    "content": "<|13.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51048": {
                    "content": "<|13.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51049": {
                    "content": "<|13.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51050": {
                    "content": "<|13.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51051": {
                    "content": "<|13.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51052": {
                    "content": "<|13.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51053": {
                    "content": "<|13.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51054": {
                    "content": "<|13.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51055": {
                    "content": "<|13.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51056": {
                    "content": "<|13.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51057": {
                    "content": "<|13.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51058": {
                    "content": "<|13.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51059": {
                    "content": "<|13.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51060": {
                    "content": "<|13.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51061": {
                    "content": "<|13.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51062": {
                    "content": "<|13.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51063": {
                    "content": "<|14.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51064": {
                    "content": "<|14.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51065": {
                    "content": "<|14.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51066": {
                    "content": "<|14.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51067": {
                    "content": "<|14.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51068": {
                    "content": "<|14.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51069": {
                    "content": "<|14.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51070": {
                    "content": "<|14.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51071": {
                    "content": "<|14.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51072": {
                    "content": "<|14.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51073": {
                    "content": "<|14.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51074": {
                    "content": "<|14.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51075": {
                    "content": "<|14.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51076": {
                    "content": "<|14.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51077": {
                    "content": "<|14.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51078": {
                    "content": "<|14.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51079": {
                    "content": "<|14.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51080": {
                    "content": "<|14.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51081": {
                    "content": "<|14.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51082": {
                    "content": "<|14.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51083": {
                    "content": "<|14.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51084": {
                    "content": "<|14.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51085": {
                    "content": "<|14.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51086": {
                    "content": "<|14.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51087": {
                    "content": "<|14.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51088": {
                    "content": "<|14.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51089": {
                    "content": "<|14.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51090": {
                    "content": "<|14.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51091": {
                    "content": "<|14.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51092": {
                    "content": "<|14.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51093": {
                    "content": "<|14.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51094": {
                    "content": "<|14.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51095": {
                    "content": "<|14.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51096": {
                    "content": "<|14.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51097": {
                    "content": "<|14.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51098": {
                    "content": "<|14.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51099": {
                    "content": "<|14.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51100": {
                    "content": "<|14.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51101": {
                    "content": "<|14.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51102": {
                    "content": "<|14.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51103": {
                    "content": "<|14.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51104": {
                    "content": "<|14.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51105": {
                    "content": "<|14.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51106": {
                    "content": "<|14.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51107": {
                    "content": "<|14.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51108": {
                    "content": "<|14.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51109": {
                    "content": "<|14.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51110": {
                    "content": "<|14.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51111": {
                    "content": "<|14.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51112": {
                    "content": "<|14.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51113": {
                    "content": "<|15.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51114": {
                    "content": "<|15.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51115": {
                    "content": "<|15.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51116": {
                    "content": "<|15.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51117": {
                    "content": "<|15.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51118": {
                    "content": "<|15.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51119": {
                    "content": "<|15.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51120": {
                    "content": "<|15.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51121": {
                    "content": "<|15.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51122": {
                    "content": "<|15.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51123": {
                    "content": "<|15.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51124": {
                    "content": "<|15.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51125": {
                    "content": "<|15.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51126": {
                    "content": "<|15.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51127": {
                    "content": "<|15.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51128": {
                    "content": "<|15.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51129": {
                    "content": "<|15.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51130": {
                    "content": "<|15.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51131": {
                    "content": "<|15.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51132": {
                    "content": "<|15.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51133": {
                    "content": "<|15.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51134": {
                    "content": "<|15.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51135": {
                    "content": "<|15.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51136": {
                    "content": "<|15.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51137": {
                    "content": "<|15.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51138": {
                    "content": "<|15.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51139": {
                    "content": "<|15.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51140": {
                    "content": "<|15.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51141": {
                    "content": "<|15.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51142": {
                    "content": "<|15.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51143": {
                    "content": "<|15.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51144": {
                    "content": "<|15.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51145": {
                    "content": "<|15.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51146": {
                    "content": "<|15.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51147": {
                    "content": "<|15.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51148": {
                    "content": "<|15.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51149": {
                    "content": "<|15.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51150": {
                    "content": "<|15.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51151": {
                    "content": "<|15.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51152": {
                    "content": "<|15.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51153": {
                    "content": "<|15.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51154": {
                    "content": "<|15.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51155": {
                    "content": "<|15.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51156": {
                    "content": "<|15.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51157": {
                    "content": "<|15.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51158": {
                    "content": "<|15.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51159": {
                    "content": "<|15.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51160": {
                    "content": "<|15.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51161": {
                    "content": "<|15.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51162": {
                    "content": "<|15.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51163": {
                    "content": "<|16.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51164": {
                    "content": "<|16.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51165": {
                    "content": "<|16.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51166": {
                    "content": "<|16.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51167": {
                    "content": "<|16.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51168": {
                    "content": "<|16.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51169": {
                    "content": "<|16.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51170": {
                    "content": "<|16.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51171": {
                    "content": "<|16.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51172": {
                    "content": "<|16.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51173": {
                    "content": "<|16.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51174": {
                    "content": "<|16.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51175": {
                    "content": "<|16.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51176": {
                    "content": "<|16.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51177": {
                    "content": "<|16.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51178": {
                    "content": "<|16.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51179": {
                    "content": "<|16.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51180": {
                    "content": "<|16.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51181": {
                    "content": "<|16.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51182": {
                    "content": "<|16.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51183": {
                    "content": "<|16.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51184": {
                    "content": "<|16.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51185": {
                    "content": "<|16.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51186": {
                    "content": "<|16.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51187": {
                    "content": "<|16.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51188": {
                    "content": "<|16.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51189": {
                    "content": "<|16.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51190": {
                    "content": "<|16.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51191": {
                    "content": "<|16.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51192": {
                    "content": "<|16.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51193": {
                    "content": "<|16.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51194": {
                    "content": "<|16.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51195": {
                    "content": "<|16.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51196": {
                    "content": "<|16.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51197": {
                    "content": "<|16.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51198": {
                    "content": "<|16.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51199": {
                    "content": "<|16.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51200": {
                    "content": "<|16.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51201": {
                    "content": "<|16.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51202": {
                    "content": "<|16.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51203": {
                    "content": "<|16.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51204": {
                    "content": "<|16.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51205": {
                    "content": "<|16.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51206": {
                    "content": "<|16.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51207": {
                    "content": "<|16.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51208": {
                    "content": "<|16.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51209": {
                    "content": "<|16.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51210": {
                    "content": "<|16.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51211": {
                    "content": "<|16.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51212": {
                    "content": "<|16.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51213": {
                    "content": "<|17.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51214": {
                    "content": "<|17.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51215": {
                    "content": "<|17.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51216": {
                    "content": "<|17.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51217": {
                    "content": "<|17.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51218": {
                    "content": "<|17.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51219": {
                    "content": "<|17.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51220": {
                    "content": "<|17.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51221": {
                    "content": "<|17.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51222": {
                    "content": "<|17.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51223": {
                    "content": "<|17.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51224": {
                    "content": "<|17.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51225": {
                    "content": "<|17.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51226": {
                    "content": "<|17.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51227": {
                    "content": "<|17.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51228": {
                    "content": "<|17.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51229": {
                    "content": "<|17.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51230": {
                    "content": "<|17.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51231": {
                    "content": "<|17.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51232": {
                    "content": "<|17.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51233": {
                    "content": "<|17.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51234": {
                    "content": "<|17.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51235": {
                    "content": "<|17.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51236": {
                    "content": "<|17.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51237": {
                    "content": "<|17.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51238": {
                    "content": "<|17.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51239": {
                    "content": "<|17.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51240": {
                    "content": "<|17.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51241": {
                    "content": "<|17.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51242": {
                    "content": "<|17.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51243": {
                    "content": "<|17.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51244": {
                    "content": "<|17.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51245": {
                    "content": "<|17.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51246": {
                    "content": "<|17.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51247": {
                    "content": "<|17.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51248": {
                    "content": "<|17.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51249": {
                    "content": "<|17.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51250": {
                    "content": "<|17.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51251": {
                    "content": "<|17.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51252": {
                    "content": "<|17.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51253": {
                    "content": "<|17.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51254": {
                    "content": "<|17.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51255": {
                    "content": "<|17.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51256": {
                    "content": "<|17.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51257": {
                    "content": "<|17.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51258": {
                    "content": "<|17.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51259": {
                    "content": "<|17.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51260": {
                    "content": "<|17.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51261": {
                    "content": "<|17.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51262": {
                    "content": "<|17.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51263": {
                    "content": "<|18.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51264": {
                    "content": "<|18.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51265": {
                    "content": "<|18.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51266": {
                    "content": "<|18.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51267": {
                    "content": "<|18.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51268": {
                    "content": "<|18.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51269": {
                    "content": "<|18.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51270": {
                    "content": "<|18.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51271": {
                    "content": "<|18.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51272": {
                    "content": "<|18.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51273": {
                    "content": "<|18.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51274": {
                    "content": "<|18.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51275": {
                    "content": "<|18.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51276": {
                    "content": "<|18.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51277": {
                    "content": "<|18.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51278": {
                    "content": "<|18.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51279": {
                    "content": "<|18.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51280": {
                    "content": "<|18.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51281": {
                    "content": "<|18.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51282": {
                    "content": "<|18.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51283": {
                    "content": "<|18.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51284": {
                    "content": "<|18.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51285": {
                    "content": "<|18.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51286": {
                    "content": "<|18.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51287": {
                    "content": "<|18.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51288": {
                    "content": "<|18.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51289": {
                    "content": "<|18.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51290": {
                    "content": "<|18.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51291": {
                    "content": "<|18.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51292": {
                    "content": "<|18.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51293": {
                    "content": "<|18.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51294": {
                    "content": "<|18.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51295": {
                    "content": "<|18.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51296": {
                    "content": "<|18.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51297": {
                    "content": "<|18.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51298": {
                    "content": "<|18.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51299": {
                    "content": "<|18.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51300": {
                    "content": "<|18.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51301": {
                    "content": "<|18.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51302": {
                    "content": "<|18.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51303": {
                    "content": "<|18.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51304": {
                    "content": "<|18.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51305": {
                    "content": "<|18.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51306": {
                    "content": "<|18.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51307": {
                    "content": "<|18.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51308": {
                    "content": "<|18.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51309": {
                    "content": "<|18.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51310": {
                    "content": "<|18.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51311": {
                    "content": "<|18.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51312": {
                    "content": "<|18.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51313": {
                    "content": "<|19.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51314": {
                    "content": "<|19.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51315": {
                    "content": "<|19.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51316": {
                    "content": "<|19.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51317": {
                    "content": "<|19.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51318": {
                    "content": "<|19.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51319": {
                    "content": "<|19.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51320": {
                    "content": "<|19.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51321": {
                    "content": "<|19.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51322": {
                    "content": "<|19.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51323": {
                    "content": "<|19.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51324": {
                    "content": "<|19.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51325": {
                    "content": "<|19.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51326": {
                    "content": "<|19.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51327": {
                    "content": "<|19.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51328": {
                    "content": "<|19.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51329": {
                    "content": "<|19.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51330": {
                    "content": "<|19.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51331": {
                    "content": "<|19.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51332": {
                    "content": "<|19.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51333": {
                    "content": "<|19.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51334": {
                    "content": "<|19.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51335": {
                    "content": "<|19.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51336": {
                    "content": "<|19.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51337": {
                    "content": "<|19.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51338": {
                    "content": "<|19.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51339": {
                    "content": "<|19.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51340": {
                    "content": "<|19.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51341": {
                    "content": "<|19.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51342": {
                    "content": "<|19.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51343": {
                    "content": "<|19.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51344": {
                    "content": "<|19.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51345": {
                    "content": "<|19.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51346": {
                    "content": "<|19.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51347": {
                    "content": "<|19.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51348": {
                    "content": "<|19.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51349": {
                    "content": "<|19.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51350": {
                    "content": "<|19.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51351": {
                    "content": "<|19.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51352": {
                    "content": "<|19.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51353": {
                    "content": "<|19.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51354": {
                    "content": "<|19.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51355": {
                    "content": "<|19.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51356": {
                    "content": "<|19.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51357": {
                    "content": "<|19.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51358": {
                    "content": "<|19.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51359": {
                    "content": "<|19.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51360": {
                    "content": "<|19.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51361": {
                    "content": "<|19.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51362": {
                    "content": "<|19.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51363": {
                    "content": "<|20.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51364": {
                    "content": "<|20.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51365": {
                    "content": "<|20.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51366": {
                    "content": "<|20.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51367": {
                    "content": "<|20.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51368": {
                    "content": "<|20.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51369": {
                    "content": "<|20.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51370": {
                    "content": "<|20.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51371": {
                    "content": "<|20.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51372": {
                    "content": "<|20.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51373": {
                    "content": "<|20.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51374": {
                    "content": "<|20.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51375": {
                    "content": "<|20.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51376": {
                    "content": "<|20.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51377": {
                    "content": "<|20.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51378": {
                    "content": "<|20.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51379": {
                    "content": "<|20.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51380": {
                    "content": "<|20.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51381": {
                    "content": "<|20.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51382": {
                    "content": "<|20.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51383": {
                    "content": "<|20.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51384": {
                    "content": "<|20.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51385": {
                    "content": "<|20.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51386": {
                    "content": "<|20.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51387": {
                    "content": "<|20.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51388": {
                    "content": "<|20.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51389": {
                    "content": "<|20.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51390": {
                    "content": "<|20.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51391": {
                    "content": "<|20.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51392": {
                    "content": "<|20.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51393": {
                    "content": "<|20.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51394": {
                    "content": "<|20.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51395": {
                    "content": "<|20.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51396": {
                    "content": "<|20.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51397": {
                    "content": "<|20.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51398": {
                    "content": "<|20.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51399": {
                    "content": "<|20.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51400": {
                    "content": "<|20.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51401": {
                    "content": "<|20.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51402": {
                    "content": "<|20.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51403": {
                    "content": "<|20.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51404": {
                    "content": "<|20.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51405": {
                    "content": "<|20.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51406": {
                    "content": "<|20.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51407": {
                    "content": "<|20.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51408": {
                    "content": "<|20.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51409": {
                    "content": "<|20.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51410": {
                    "content": "<|20.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51411": {
                    "content": "<|20.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51412": {
                    "content": "<|20.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51413": {
                    "content": "<|21.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51414": {
                    "content": "<|21.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51415": {
                    "content": "<|21.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51416": {
                    "content": "<|21.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51417": {
                    "content": "<|21.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51418": {
                    "content": "<|21.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51419": {
                    "content": "<|21.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51420": {
                    "content": "<|21.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51421": {
                    "content": "<|21.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51422": {
                    "content": "<|21.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51423": {
                    "content": "<|21.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51424": {
                    "content": "<|21.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51425": {
                    "content": "<|21.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51426": {
                    "content": "<|21.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51427": {
                    "content": "<|21.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51428": {
                    "content": "<|21.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51429": {
                    "content": "<|21.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51430": {
                    "content": "<|21.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51431": {
                    "content": "<|21.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51432": {
                    "content": "<|21.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51433": {
                    "content": "<|21.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51434": {
                    "content": "<|21.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51435": {
                    "content": "<|21.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51436": {
                    "content": "<|21.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51437": {
                    "content": "<|21.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51438": {
                    "content": "<|21.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51439": {
                    "content": "<|21.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51440": {
                    "content": "<|21.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51441": {
                    "content": "<|21.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51442": {
                    "content": "<|21.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51443": {
                    "content": "<|21.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51444": {
                    "content": "<|21.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51445": {
                    "content": "<|21.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51446": {
                    "content": "<|21.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51447": {
                    "content": "<|21.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51448": {
                    "content": "<|21.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51449": {
                    "content": "<|21.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51450": {
                    "content": "<|21.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51451": {
                    "content": "<|21.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51452": {
                    "content": "<|21.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51453": {
                    "content": "<|21.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51454": {
                    "content": "<|21.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51455": {
                    "content": "<|21.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51456": {
                    "content": "<|21.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51457": {
                    "content": "<|21.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51458": {
                    "content": "<|21.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51459": {
                    "content": "<|21.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51460": {
                    "content": "<|21.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51461": {
                    "content": "<|21.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51462": {
                    "content": "<|21.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51463": {
                    "content": "<|22.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51464": {
                    "content": "<|22.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51465": {
                    "content": "<|22.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51466": {
                    "content": "<|22.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51467": {
                    "content": "<|22.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51468": {
                    "content": "<|22.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51469": {
                    "content": "<|22.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51470": {
                    "content": "<|22.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51471": {
                    "content": "<|22.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51472": {
                    "content": "<|22.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51473": {
                    "content": "<|22.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51474": {
                    "content": "<|22.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51475": {
                    "content": "<|22.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51476": {
                    "content": "<|22.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51477": {
                    "content": "<|22.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51478": {
                    "content": "<|22.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51479": {
                    "content": "<|22.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51480": {
                    "content": "<|22.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51481": {
                    "content": "<|22.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51482": {
                    "content": "<|22.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51483": {
                    "content": "<|22.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51484": {
                    "content": "<|22.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51485": {
                    "content": "<|22.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51486": {
                    "content": "<|22.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51487": {
                    "content": "<|22.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51488": {
                    "content": "<|22.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51489": {
                    "content": "<|22.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51490": {
                    "content": "<|22.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51491": {
                    "content": "<|22.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51492": {
                    "content": "<|22.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51493": {
                    "content": "<|22.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51494": {
                    "content": "<|22.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51495": {
                    "content": "<|22.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51496": {
                    "content": "<|22.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51497": {
                    "content": "<|22.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51498": {
                    "content": "<|22.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51499": {
                    "content": "<|22.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51500": {
                    "content": "<|22.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51501": {
                    "content": "<|22.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51502": {
                    "content": "<|22.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51503": {
                    "content": "<|22.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51504": {
                    "content": "<|22.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51505": {
                    "content": "<|22.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51506": {
                    "content": "<|22.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51507": {
                    "content": "<|22.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51508": {
                    "content": "<|22.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51509": {
                    "content": "<|22.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51510": {
                    "content": "<|22.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51511": {
                    "content": "<|22.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51512": {
                    "content": "<|22.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51513": {
                    "content": "<|23.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51514": {
                    "content": "<|23.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51515": {
                    "content": "<|23.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51516": {
                    "content": "<|23.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51517": {
                    "content": "<|23.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51518": {
                    "content": "<|23.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51519": {
                    "content": "<|23.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51520": {
                    "content": "<|23.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51521": {
                    "content": "<|23.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51522": {
                    "content": "<|23.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51523": {
                    "content": "<|23.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51524": {
                    "content": "<|23.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51525": {
                    "content": "<|23.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51526": {
                    "content": "<|23.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51527": {
                    "content": "<|23.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51528": {
                    "content": "<|23.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51529": {
                    "content": "<|23.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51530": {
                    "content": "<|23.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51531": {
                    "content": "<|23.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51532": {
                    "content": "<|23.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51533": {
                    "content": "<|23.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51534": {
                    "content": "<|23.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51535": {
                    "content": "<|23.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51536": {
                    "content": "<|23.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51537": {
                    "content": "<|23.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51538": {
                    "content": "<|23.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51539": {
                    "content": "<|23.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51540": {
                    "content": "<|23.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51541": {
                    "content": "<|23.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51542": {
                    "content": "<|23.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51543": {
                    "content": "<|23.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51544": {
                    "content": "<|23.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51545": {
                    "content": "<|23.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51546": {
                    "content": "<|23.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51547": {
                    "content": "<|23.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51548": {
                    "content": "<|23.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51549": {
                    "content": "<|23.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51550": {
                    "content": "<|23.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51551": {
                    "content": "<|23.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51552": {
                    "content": "<|23.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51553": {
                    "content": "<|23.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51554": {
                    "content": "<|23.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51555": {
                    "content": "<|23.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51556": {
                    "content": "<|23.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51557": {
                    "content": "<|23.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51558": {
                    "content": "<|23.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51559": {
                    "content": "<|23.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51560": {
                    "content": "<|23.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51561": {
                    "content": "<|23.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51562": {
                    "content": "<|23.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51563": {
                    "content": "<|24.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51564": {
                    "content": "<|24.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51565": {
                    "content": "<|24.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51566": {
                    "content": "<|24.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51567": {
                    "content": "<|24.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51568": {
                    "content": "<|24.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51569": {
                    "content": "<|24.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51570": {
                    "content": "<|24.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51571": {
                    "content": "<|24.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51572": {
                    "content": "<|24.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51573": {
                    "content": "<|24.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51574": {
                    "content": "<|24.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51575": {
                    "content": "<|24.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51576": {
                    "content": "<|24.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51577": {
                    "content": "<|24.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51578": {
                    "content": "<|24.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51579": {
                    "content": "<|24.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51580": {
                    "content": "<|24.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51581": {
                    "content": "<|24.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51582": {
                    "content": "<|24.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51583": {
                    "content": "<|24.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51584": {
                    "content": "<|24.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51585": {
                    "content": "<|24.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51586": {
                    "content": "<|24.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51587": {
                    "content": "<|24.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51588": {
                    "content": "<|24.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51589": {
                    "content": "<|24.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51590": {
                    "content": "<|24.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51591": {
                    "content": "<|24.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51592": {
                    "content": "<|24.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51593": {
                    "content": "<|24.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51594": {
                    "content": "<|24.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51595": {
                    "content": "<|24.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51596": {
                    "content": "<|24.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51597": {
                    "content": "<|24.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51598": {
                    "content": "<|24.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51599": {
                    "content": "<|24.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51600": {
                    "content": "<|24.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51601": {
                    "content": "<|24.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51602": {
                    "content": "<|24.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51603": {
                    "content": "<|24.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51604": {
                    "content": "<|24.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51605": {
                    "content": "<|24.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51606": {
                    "content": "<|24.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51607": {
                    "content": "<|24.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51608": {
                    "content": "<|24.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51609": {
                    "content": "<|24.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51610": {
                    "content": "<|24.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51611": {
                    "content": "<|24.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51612": {
                    "content": "<|24.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51613": {
                    "content": "<|25.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51614": {
                    "content": "<|25.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51615": {
                    "content": "<|25.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51616": {
                    "content": "<|25.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51617": {
                    "content": "<|25.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51618": {
                    "content": "<|25.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51619": {
                    "content": "<|25.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51620": {
                    "content": "<|25.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51621": {
                    "content": "<|25.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51622": {
                    "content": "<|25.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51623": {
                    "content": "<|25.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51624": {
                    "content": "<|25.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51625": {
                    "content": "<|25.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51626": {
                    "content": "<|25.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51627": {
                    "content": "<|25.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51628": {
                    "content": "<|25.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51629": {
                    "content": "<|25.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51630": {
                    "content": "<|25.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51631": {
                    "content": "<|25.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51632": {
                    "content": "<|25.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51633": {
                    "content": "<|25.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51634": {
                    "content": "<|25.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51635": {
                    "content": "<|25.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51636": {
                    "content": "<|25.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51637": {
                    "content": "<|25.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51638": {
                    "content": "<|25.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51639": {
                    "content": "<|25.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51640": {
                    "content": "<|25.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51641": {
                    "content": "<|25.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51642": {
                    "content": "<|25.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51643": {
                    "content": "<|25.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51644": {
                    "content": "<|25.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51645": {
                    "content": "<|25.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51646": {
                    "content": "<|25.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51647": {
                    "content": "<|25.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51648": {
                    "content": "<|25.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51649": {
                    "content": "<|25.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51650": {
                    "content": "<|25.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51651": {
                    "content": "<|25.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51652": {
                    "content": "<|25.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51653": {
                    "content": "<|25.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51654": {
                    "content": "<|25.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51655": {
                    "content": "<|25.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51656": {
                    "content": "<|25.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51657": {
                    "content": "<|25.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51658": {
                    "content": "<|25.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51659": {
                    "content": "<|25.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51660": {
                    "content": "<|25.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51661": {
                    "content": "<|25.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51662": {
                    "content": "<|25.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51663": {
                    "content": "<|26.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51664": {
                    "content": "<|26.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51665": {
                    "content": "<|26.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51666": {
                    "content": "<|26.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51667": {
                    "content": "<|26.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51668": {
                    "content": "<|26.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51669": {
                    "content": "<|26.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51670": {
                    "content": "<|26.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51671": {
                    "content": "<|26.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51672": {
                    "content": "<|26.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51673": {
                    "content": "<|26.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51674": {
                    "content": "<|26.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51675": {
                    "content": "<|26.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51676": {
                    "content": "<|26.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51677": {
                    "content": "<|26.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51678": {
                    "content": "<|26.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51679": {
                    "content": "<|26.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51680": {
                    "content": "<|26.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51681": {
                    "content": "<|26.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51682": {
                    "content": "<|26.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51683": {
                    "content": "<|26.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51684": {
                    "content": "<|26.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51685": {
                    "content": "<|26.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51686": {
                    "content": "<|26.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51687": {
                    "content": "<|26.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51688": {
                    "content": "<|26.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51689": {
                    "content": "<|26.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51690": {
                    "content": "<|26.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51691": {
                    "content": "<|26.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51692": {
                    "content": "<|26.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51693": {
                    "content": "<|26.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51694": {
                    "content": "<|26.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51695": {
                    "content": "<|26.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51696": {
                    "content": "<|26.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51697": {
                    "content": "<|26.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51698": {
                    "content": "<|26.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51699": {
                    "content": "<|26.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51700": {
                    "content": "<|26.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51701": {
                    "content": "<|26.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51702": {
                    "content": "<|26.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51703": {
                    "content": "<|26.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51704": {
                    "content": "<|26.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51705": {
                    "content": "<|26.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51706": {
                    "content": "<|26.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51707": {
                    "content": "<|26.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51708": {
                    "content": "<|26.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51709": {
                    "content": "<|26.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51710": {
                    "content": "<|26.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51711": {
                    "content": "<|26.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51712": {
                    "content": "<|26.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51713": {
                    "content": "<|27.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51714": {
                    "content": "<|27.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51715": {
                    "content": "<|27.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51716": {
                    "content": "<|27.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51717": {
                    "content": "<|27.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51718": {
                    "content": "<|27.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51719": {
                    "content": "<|27.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51720": {
                    "content": "<|27.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51721": {
                    "content": "<|27.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51722": {
                    "content": "<|27.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51723": {
                    "content": "<|27.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51724": {
                    "content": "<|27.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51725": {
                    "content": "<|27.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51726": {
                    "content": "<|27.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51727": {
                    "content": "<|27.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51728": {
                    "content": "<|27.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51729": {
                    "content": "<|27.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51730": {
                    "content": "<|27.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51731": {
                    "content": "<|27.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51732": {
                    "content": "<|27.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51733": {
                    "content": "<|27.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51734": {
                    "content": "<|27.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51735": {
                    "content": "<|27.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51736": {
                    "content": "<|27.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51737": {
                    "content": "<|27.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51738": {
                    "content": "<|27.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51739": {
                    "content": "<|27.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51740": {
                    "content": "<|27.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51741": {
                    "content": "<|27.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51742": {
                    "content": "<|27.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51743": {
                    "content": "<|27.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51744": {
                    "content": "<|27.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51745": {
                    "content": "<|27.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51746": {
                    "content": "<|27.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51747": {
                    "content": "<|27.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51748": {
                    "content": "<|27.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51749": {
                    "content": "<|27.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51750": {
                    "content": "<|27.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51751": {
                    "content": "<|27.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51752": {
                    "content": "<|27.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51753": {
                    "content": "<|27.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51754": {
                    "content": "<|27.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51755": {
                    "content": "<|27.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51756": {
                    "content": "<|27.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51757": {
                    "content": "<|27.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51758": {
                    "content": "<|27.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51759": {
                    "content": "<|27.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51760": {
                    "content": "<|27.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51761": {
                    "content": "<|27.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51762": {
                    "content": "<|27.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51763": {
                    "content": "<|28.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51764": {
                    "content": "<|28.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51765": {
                    "content": "<|28.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51766": {
                    "content": "<|28.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51767": {
                    "content": "<|28.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51768": {
                    "content": "<|28.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51769": {
                    "content": "<|28.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51770": {
                    "content": "<|28.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51771": {
                    "content": "<|28.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51772": {
                    "content": "<|28.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51773": {
                    "content": "<|28.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51774": {
                    "content": "<|28.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51775": {
                    "content": "<|28.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51776": {
                    "content": "<|28.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51777": {
                    "content": "<|28.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51778": {
                    "content": "<|28.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51779": {
                    "content": "<|28.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51780": {
                    "content": "<|28.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51781": {
                    "content": "<|28.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51782": {
                    "content": "<|28.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51783": {
                    "content": "<|28.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51784": {
                    "content": "<|28.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51785": {
                    "content": "<|28.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51786": {
                    "content": "<|28.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51787": {
                    "content": "<|28.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51788": {
                    "content": "<|28.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51789": {
                    "content": "<|28.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51790": {
                    "content": "<|28.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51791": {
                    "content": "<|28.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51792": {
                    "content": "<|28.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51793": {
                    "content": "<|28.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51794": {
                    "content": "<|28.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51795": {
                    "content": "<|28.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51796": {
                    "content": "<|28.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51797": {
                    "content": "<|28.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51798": {
                    "content": "<|28.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51799": {
                    "content": "<|28.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51800": {
                    "content": "<|28.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51801": {
                    "content": "<|28.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51802": {
                    "content": "<|28.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51803": {
                    "content": "<|28.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51804": {
                    "content": "<|28.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51805": {
                    "content": "<|28.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51806": {
                    "content": "<|28.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51807": {
                    "content": "<|28.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51808": {
                    "content": "<|28.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51809": {
                    "content": "<|28.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51810": {
                    "content": "<|28.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51811": {
                    "content": "<|28.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51812": {
                    "content": "<|28.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51813": {
                    "content": "<|29.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51814": {
                    "content": "<|29.02|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51815": {
                    "content": "<|29.04|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51816": {
                    "content": "<|29.06|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51817": {
                    "content": "<|29.08|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51818": {
                    "content": "<|29.10|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51819": {
                    "content": "<|29.12|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51820": {
                    "content": "<|29.14|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51821": {
                    "content": "<|29.16|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51822": {
                    "content": "<|29.18|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51823": {
                    "content": "<|29.20|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51824": {
                    "content": "<|29.22|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51825": {
                    "content": "<|29.24|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51826": {
                    "content": "<|29.26|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51827": {
                    "content": "<|29.28|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51828": {
                    "content": "<|29.30|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51829": {
                    "content": "<|29.32|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51830": {
                    "content": "<|29.34|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51831": {
                    "content": "<|29.36|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51832": {
                    "content": "<|29.38|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51833": {
                    "content": "<|29.40|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51834": {
                    "content": "<|29.42|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51835": {
                    "content": "<|29.44|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51836": {
                    "content": "<|29.46|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51837": {
                    "content": "<|29.48|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51838": {
                    "content": "<|29.50|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51839": {
                    "content": "<|29.52|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51840": {
                    "content": "<|29.54|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51841": {
                    "content": "<|29.56|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51842": {
                    "content": "<|29.58|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51843": {
                    "content": "<|29.60|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51844": {
                    "content": "<|29.62|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51845": {
                    "content": "<|29.64|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51846": {
                    "content": "<|29.66|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51847": {
                    "content": "<|29.68|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51848": {
                    "content": "<|29.70|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51849": {
                    "content": "<|29.72|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51850": {
                    "content": "<|29.74|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51851": {
                    "content": "<|29.76|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51852": {
                    "content": "<|29.78|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51853": {
                    "content": "<|29.80|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51854": {
                    "content": "<|29.82|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51855": {
                    "content": "<|29.84|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51856": {
                    "content": "<|29.86|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51857": {
                    "content": "<|29.88|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51858": {
                    "content": "<|29.90|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51859": {
                    "content": "<|29.92|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51860": {
                    "content": "<|29.94|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51861": {
                    "content": "<|29.96|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51862": {
                    "content": "<|29.98|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
                "51863": {
                    "content": "<|30.00|>",
                    "lstrip": False,
                    "normalized": True,
                    "rstrip": False,
                    "single_word": False,
                    "special": False,
                },
            },
            "additional_special_tokens": [
                "<|startoftranscript|>",
                "<|en|>",
                "<|zh|>",
                "<|de|>",
                "<|es|>",
                "<|ru|>",
                "<|ko|>",
                "<|fr|>",
                "<|ja|>",
                "<|pt|>",
                "<|tr|>",
                "<|pl|>",
                "<|ca|>",
                "<|nl|>",
                "<|ar|>",
                "<|sv|>",
                "<|it|>",
                "<|id|>",
                "<|hi|>",
                "<|fi|>",
                "<|vi|>",
                "<|iw|>",
                "<|uk|>",
                "<|el|>",
                "<|ms|>",
                "<|cs|>",
                "<|ro|>",
                "<|da|>",
                "<|hu|>",
                "<|ta|>",
                "<|no|>",
                "<|th|>",
                "<|ur|>",
                "<|hr|>",
                "<|bg|>",
                "<|lt|>",
                "<|la|>",
                "<|mi|>",
                "<|ml|>",
                "<|cy|>",
                "<|sk|>",
                "<|te|>",
                "<|fa|>",
                "<|lv|>",
                "<|bn|>",
                "<|sr|>",
                "<|az|>",
                "<|sl|>",
                "<|kn|>",
                "<|et|>",
                "<|mk|>",
                "<|br|>",
                "<|eu|>",
                "<|is|>",
                "<|hy|>",
                "<|ne|>",
                "<|mn|>",
                "<|bs|>",
                "<|kk|>",
                "<|sq|>",
                "<|sw|>",
                "<|gl|>",
                "<|mr|>",
                "<|pa|>",
                "<|si|>",
                "<|km|>",
                "<|sn|>",
                "<|yo|>",
                "<|so|>",
                "<|af|>",
                "<|oc|>",
                "<|ka|>",
                "<|be|>",
                "<|tg|>",
                "<|sd|>",
                "<|gu|>",
                "<|am|>",
                "<|yi|>",
                "<|lo|>",
                "<|uz|>",
                "<|fo|>",
                "<|ht|>",
                "<|ps|>",
                "<|tk|>",
                "<|nn|>",
                "<|mt|>",
                "<|sa|>",
                "<|lb|>",
                "<|my|>",
                "<|bo|>",
                "<|tl|>",
                "<|mg|>",
                "<|as|>",
                "<|tt|>",
                "<|haw|>",
                "<|ln|>",
                "<|ha|>",
                "<|ba|>",
                "<|jw|>",
                "<|su|>",
                "<|translate|>",
                "<|transcribe|>",
                "<|startoflm|>",
                "<|startofprev|>",
                "<|nocaptions|>",
                "<|notimestamps|>",
            ],
            "bos_token": "<|endoftext|>",
            "clean_up_tokenization_spaces": True,
            "eos_token": "<|endoftext|>",
            "errors": "replace",
            "model_max_length": 1024,
            "pad_token": "<|endoftext|>",
            "processor_class": "WhisperProcessor",
            "return_attention_mask": False,
            "tokenizer_class": "WhisperTokenizer",
            "trust_remote_code": False,
            "unk_token": "<|endoftext|>",
            "use_fast": True,
        }
        from tokenizers import AddedToken # type: ignore[import-untyped,import-not-found,unused-ignore]
        for token_id, token_kwargs in list(config["added_tokens_decoder"].items()): # type: ignore[attr-defined]
            config["added_tokens_decoder"][token_id] = AddedToken(**token_kwargs) # type: ignore[index]
        return config
